@@ -142,9 +142,9 @@ class AssignmentOptions:
         if __debug__:
             def stub(
                 *,
-                principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
+                principal: typing.Union[PrincipalProperty, typing.Dict[str, typing.Any]],
                 target_id: builtins.str,
-                target_type: typing.Optional["TargetTypes"] = None,
+                target_type: typing.Optional[TargetTypes] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -224,10 +224,10 @@ class AssignmentProps(AssignmentOptions):
         if __debug__:
             def stub(
                 *,
-                principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
+                principal: typing.Union[PrincipalProperty, typing.Dict[str, typing.Any]],
                 target_id: builtins.str,
-                target_type: typing.Optional["TargetTypes"] = None,
-                permission_set: "IPermissionSet",
+                target_type: typing.Optional[TargetTypes] = None,
+                permission_set: IPermissionSet,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -463,9 +463,9 @@ class _IPermissionSetProxy(
             def stub(
                 id: builtins.str,
                 *,
-                principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
+                principal: typing.Union[PrincipalProperty, typing.Dict[str, typing.Any]],
                 target_id: builtins.str,
-                target_type: typing.Optional["TargetTypes"] = None,
+                target_type: typing.Optional[TargetTypes] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -661,9 +661,9 @@ class PermissionSet(
             def stub(
                 id: builtins.str,
                 *,
-                principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
+                principal: typing.Union[PrincipalProperty, typing.Dict[str, typing.Any]],
                 target_id: builtins.str,
-                target_type: typing.Optional["TargetTypes"] = None,
+                target_type: typing.Optional[TargetTypes] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -981,7 +981,7 @@ class PrincipalProperty:
             def stub(
                 *,
                 principal_id: builtins.str,
-                principal_type: "PrincipalTypes",
+                principal_type: PrincipalTypes,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
